@@ -8,7 +8,7 @@ http://php.cheetan.net/
 	
 class CDBTextsql extends CDBCommon
 {
-	function connect( $host, $user, $pswd, $db )
+	function connect( $config )
 	{
 		return true;
 	}
@@ -23,13 +23,14 @@ class CDBTextsql extends CDBCommon
 	function findall( $connect, $table, $condition = "", $order = "", $limit = "", $group = "" )
 	{
 		$db		= new CTextDB();
-		return $db->select( $condition, $order, $table );
+		return $db->select( $condition, $order, $table, $limit );
 	}
 	
 	
 	function getcount( $connect, $table, $condition = "", $limit = "" )
 	{
-		return count( $this->findall( $connect, $table, $condition, "", $limit ) );
+		$db		= new CTextDB();
+		return $db->count( $condition, $table );
 	}
 	
 	
